icsemantic.catalog.tests.base.OntoCatalogFunctionalTestCase

Package platecom :: Package ontocatalog :: Package tests :: Module base :: Class OntoCatalogFunctionalTestCase |
[hide private]
[frames] | no frames]

# Class OntoCatalogFunctionalTestCase

source code

    Products.PloneTestCase.PloneTestCase.FunctionalTestCase --+
                                                              |
                                                             OntoCatalogFunctionalTestCase

We use this class for functional integration tests that use doctest syntax. Again, we can put basic common utility or setup code in here.

Instance Methods | [hide private]
setUp(self) | source code